@@ -63,7 +63,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.10',
+        'version': '2.0.11',
         'name': 'IPCMB feature selector',
         'keywords': 'rpi primitives',
         'source': {
@@ -91,32 +91,31 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
-        self.is_feature_selection = True
-        self.index = None
-        self.training_inputs = None
-        self.training_outputs = None
-        self.fitted = False
+        self._index = None
+        self._training_inputs = None
+        self._training_outputs = None
+        self._fitted = False
 
     def set_training_data(self, *, inputs: Inputs, outputs: Outputs) -> None:
-        self.training_inputs = inputs
-        self.training_outputs = outputs
-        self.fitted = False
+        self._training_inputs = inputs
+        self._training_outputs = outputs
+        self._fitted = False
 
 
     def fit(self, *, timeout: float = None, iterations: int = None) -> None:
-        if self.fitted:
+        if self._fitted:
             return CallResult(None)
 
-        if self.training_inputs.any() == None or self.training_outputs.any() == None:
+        if self._training_inputs.any() == None or self._training_outputs.any() == None:
             raise ValueError('Missing training data, or missing values exist.')
 
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self.training_inputs, 'trainlabel': self.training_outputs})
+        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs, 'hm_bins': hyperparams['n_bins']})
 
         a = rpi_feature_selection_toolbox.initialize()
         index = np.reshape(np.array(a.IPCMBplus()), [-1, ])
 
-        self.index = (index - 1).astype(int)
-        self.fitted = True
+        self._index = (index - 1).astype(int)
+        self._fitted = True
 
         os.remove('rpi_data.mat')
 
@@ -124,8 +123,8 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
 
     def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
-        if self.fitted:
-            return CallResult(inputs[:, self.index])
+        if self._fitted:
+            return CallResult(inputs[:, self._index])
         else:
             raise ValueError('Model should be fitted first.')
 
